tomotok.core.geometry package
=============================

.. automodule:: tomotok.core.geometry
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

tomotok.core.geometry.analytical module
---------------------------------------

.. automodule:: tomotok.core.geometry.analytical
    :members:
    :undoc-members:
    :show-inheritance:

tomotok.core.geometry.generators module
---------------------------------------

.. automodule:: tomotok.core.geometry.generators
    :members:
    :undoc-members:
    :show-inheritance:

tomotok.core.geometry.grids module
----------------------------------

.. automodule:: tomotok.core.geometry.grids
    :members:
    :undoc-members:
    :show-inheritance:

tomotok.core.geometry.handler module
------------------------------------

.. automodule:: tomotok.core.geometry.handler
    :members:
    :undoc-members:
    :show-inheritance:

tomotok.core.geometry.io module
-------------------------------

.. automodule:: tomotok.core.geometry.io
    :members:
    :undoc-members:
    :show-inheritance:

tomotok.core.geometry.los module
--------------------------------

.. automodule:: tomotok.core.geometry.los
    :members:
    :undoc-members:
    :show-inheritance:


